aboutsummaryrefslogtreecommitdiff
path: root/libbbot/build-config.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'libbbot/build-config.hxx')
-rw-r--r--libbbot/build-config.hxx12
1 files changed, 7 insertions, 5 deletions
diff --git a/libbbot/build-config.hxx b/libbbot/build-config.hxx
index 5c9296d..a7cc6a2 100644
--- a/libbbot/build-config.hxx
+++ b/libbbot/build-config.hxx
@@ -11,6 +11,7 @@
#include <iosfwd>
#include <libbutl/path.mxx>
+#include <libbutl/optional.mxx>
#include <libbutl/tab-parser.mxx>
#include <libbutl/target-triplet.mxx>
@@ -24,11 +25,12 @@ namespace bbot
//
struct build_config
{
- std::string machine_pattern; // Machine name pattern.
- std::string name; // Configuration name.
- butl::target_triplet target;
+ std::string machine_pattern; // Machine name pattern.
+ std::string name; // Configuration name.
+ butl::target_triplet target; // Build target.
+ butl::optional<std::string> environment; // Build environment name.
std::vector<std::string> classes;
- std::vector<std::string> args; // Note: quoting is preserved.
+ std::vector<std::string> args; // Note: quoting is preserved.
// Warning-detecting regular expressions. Note that quoting is preserved.
//
@@ -52,7 +54,7 @@ namespace bbot
//
// buildtab consists of lines in the following format:
//
- // <machine-pattern> <config> <target> <classes> [<config-arg>]* [<warning-regex>]*
+ // <machine-pattern> <config> <target>[/<environment>] <classes> [<config-arg>]* [<warning-regex>]*
//
using butl::tab_parsing;